summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteaccount.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteaccount.h')
-rw-r--r--kopete/libkopete/kopeteaccount.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/libkopete/kopeteaccount.h b/kopete/libkopete/kopeteaccount.h
index 44f12eb1..205b795f 100644
--- a/kopete/libkopete/kopeteaccount.h
+++ b/kopete/libkopete/kopeteaccount.h
@@ -364,16 +364,16 @@ protected:
* You shouldn't ever call this method yourself. To add contacts, use @ref addContact().
*
* This method is called by @ref addContact(). In this method, you should create the
* new custom @ref Contact, using @p tqparentContact as the tqparent.
*
* If the metacontact is not temporary and the protocol supports it, you can add the
* contact to the server.
*
* @param contactId the ID of the contact to create
* @param tqparentContact the metacontact to add this contact to
* @return @c true if creating the contact succeeded, @c false on failure.
*/
- virtual bool createContact( const TQString &contactId, MetaContact *tqparentContact ) =0;
+ virtual bool createContact( const TQString &contactId, MetaContact *parentContact ) =0;
/**
@@ -364,16 +364,16 @@ protected:
*
* This method is called by @ref addContact(). In this method, you should create the
- * new custom @ref Contact, using @p tqparentContact as the tqparent.
+ * new custom @ref Contact, using @p parentContact as the tqparent.
*
* If the metacontact is not temporary and the protocol supports it, you can add the
@@ -364,16 +364,16 @@ protected:
*
* @param contactId the ID of the contact to create
- * @param tqparentContact the metacontact to add this contact to
+ * @param parentContact the metacontact to add this contact to
* @return @c true if creating the contact succeeded, @c false on failure.
*/